<?php
/* $Id: german-iso-8859-15.inc.php,v 2.35 2005/11/17 13:15:25 cybot_tm Exp $ */

/**
 * For suggestions concerning this file please contact
 *     Alexander M. Turek <rabus at users.sourceforge.net>.
 *
 * Bei Verbesserungsvorschlgen diese Datei betreffend wenden Sie sich bitte an
 *     Alexander M. Turek <rabus at users.sourceforge.net>.
 */

$charset = 'iso-8859-15';
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = '.';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('So', 'Mo', 'Di', 'Mi', 'Do', 'Fr', 'Sa');
$month = array('Januar', 'Februar', 'Mrz', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d. %B %Y um %H:%M';
$timespanfmt = '%s Tage, %s Stunden, %s Minuten und %s Sekunden';

$strAbortedClients = 'Abgebrochen';
$strAbsolutePathToDocSqlDir = 'Bitte geben Sie den vollstndigen Pfad auf dem Webserver zum docSQL-Verzeichnis ein.';
$strAccessDeniedExplanation = 'phpMyAdmin hat versucht eine Verbindung zum MySQL-Server aufzubauen, jedoch hat dieser die Verbindung zurckgewiesen. Sie sollten Ihre Einstellungen fr Host, Benutzername und Kennwort in Ihrer config.inc.php berprfen und sich vergewissern, dass diese den Informationen, welche sie vom Administrator erhalten haben, entsprechen.';
$strAccessDenied = 'Zugriff verweigert.';
$strAction = 'Aktion';
$strAddAutoIncrement = 'AUTO_INCREMENT-Wert hinzufgen';
$strAddConstraints = 'Constraints hinzufgen';
$strAddDeleteColumn = 'Spalten hinzufgen/entfernen';
$strAddDeleteRow = 'Zeilen hinzufgen/entfernen';
$strAddDropDatabase = 'DROP DATABASE hinzufgen';
$strAddedColumnComment = 'Spaltenkommentar wurde hinzugefgt';
$strAddedColumnRelation = 'Spaltenbeziehung wurde hinzugefgt';
$strAddFields = '%s Felder hinzufgen';
$strAddHeaderComment = 'Individuelle Kommentare fr den Kopfbereich (\\n erzeugt einen Zeilenumbruch)';
$strAddIfNotExists = 'Mit \'IF NOT EXISTS\'';
$strAddIntoComments = 'In Kommentarbereich einbeziehen';
$strAddNewField = 'Neue Felder hinzufgen';
$strAddPrivilegesOnDb = 'Rechte zu folgender Datenbank hinzufgen';
$strAddPrivilegesOnTbl = 'Rechte zu folgender Tabelle hinzufgen';
$strAddSearchConditions = 'Eigenes Filterkriterium (Argumente fr den WHERE-Ausdruck):';
$strAddToIndex = '%s&nbsp;Spalten zum Index hinzufgen';
$strAddUserMessage = 'Der Benutzer wurde hinzugefgt.';
$strAddUser = 'Neuen Benutzer hinzufgen';
$strAdministration = 'Administration';
$strAffectedRows = ' Betroffene Datenstze: ';
$strAfterInsertBack = 'zurck';
$strAfterInsertNewInsert = 'anschlieend einen weiteren Datensatz einfgen';
$strAfterInsertNext = 'nchste Zeile bearbeiten';
$strAfterInsertSame = 'Zurck zu dieser Seite';
$strAfter = 'Nach %s';
$strAll = 'Alle';
$strAllTableSameWidth = 'Sollen alle Tabellen mit der gleichen Breite angezeigt werden?';
$strAlterOrderBy = 'Tabelle sortieren nach';
$strAnalyzeTable = 'Analysiere Tabelle';
$strAnd = 'und';
$strAnIndex = 'Ein Index wurde in %s erzeugt';
$strAnyHost = 'Jeder Host';
$strAny = 'Jeder';
$strAnyUser = 'Jeder Benutzer';
$strApproximateCount = 'Es kann sich hierbei um Nherungswerte handeln. Bitte lesen Sie auch FAQ 3.11';
$strAPrimaryKey = 'Ein Primrschlssel wurde in %s erzeugt';
$strArabic = 'Arabisch';
$strArmenian = 'Armenisch';
$strAscending = 'aufsteigend';
$strAtBeginningOfTable = 'An den Anfang der Tabelle';
$strAtEndOfTable = 'An das Ende der Tabelle';
$strAttr = 'Attribute';
$strAutodetect = 'Autom. Erkennung';
$strAutomaticLayout = 'Automatische Anordnung';

$strBack = 'Zurck';
$strBaltic = 'Baltisch';
$strBeginCut = 'AUSSCHNITTSANFANG';
$strBeginRaw = 'BEGINN DER AUSGABE';
$strBinary = 'Binr';
$strBinaryDoNotEdit = 'Binr - nicht editierbar!';
$strBinaryLog = 'Binres Protokoll';
$strBinLogEventType = 'Ereignistyp';
$strBinLogInfo = 'Information';
$strBinLogName = 'Protokoll';
$strBinLogOriginalPosition = 'Ursprungsposition';
$strBinLogPosition = 'Position';
$strBinLogServerId = 'Server-ID';
$strBookmarkAllUsers = 'Diese gespeicherte SQL-Abfrage fr jeden Benutzer verfgbar machen';
$strBookmarkDeleted = 'SQL-Abfrage wurde gelscht.';
$strBookmarkLabel = 'Titel';
$strBookmarkQuery = 'Gespeicherte SQL-Abfrage';
$strBookmarkThis = 'SQL-Abfrage speichern';
$strBookmarkView = 'Nur zeigen';
$strBrowse = 'Anzeigen';
$strBrowseForeignValues = 'Fremdschlsselwerte ansehen';
$strBufferPoolActivity = 'Speicherpuffer-Aktivitt';
$strBufferPool = 'Speicherpuffer';
$strBufferPoolUsage = 'Auslastung des Speicherpuffers';
$strBufferReadMisses = 'Fehlgeschlagene Leseanfragen';
$strBufferReadMissesInPercent = 'Fehlgeschlagene Leseanfragen in %';
$strBufferWriteWaitsInPercent = 'Schreibverzgerungen in %';
$strBufferWriteWaits = 'Schreibverzgerungen';
$strBulgarian = 'Bulgarisch';
$strBusyPages = 'Ausgelastete Seiten';
$strBzError = 'phpMyAdmin konnte die Datei wegen eines Fehler in der Bz2-Erweiterung in dieser php-Version nicht komprimieren. Es wird deshalb empfohlen die Einstellung <code>$cfg[\'BZipDump\']</code> in Ihrer phpMyAdmin-Konfiguration auf <code>FALSE</code> zu setzen. Falls Sie die Bz2-Kompressionsfunktionen dennoch nutzen wollen, so sollten Sie eine neuere php-Version installieren. Bitte lesen Sie auch den php-Bugreport %s fr weitere Informationen.';
$strBzip = 'BZip-komprimiert';

$strCalendar = 'Kalender';
$strCanNotLoadImportPlugins = 'Die Import-Plugins konnten nicht geladen werden. Bitte berprfen Sie Ihre phpMyAdmin-Installation.';
$strCannotLogin = 'Die Anmeldung am MySQL-Server ist fehlgeschlagen.';
$strCantLoad = 'Die Erweiterung [a@http://php.net/%1$s@Documentation][em]%1$s[/em][/a] kann nicht geladen werden. Bitte berprfen Sie Ihre PHP-Konfiguration.';
$strCantLoadRecodeIconv = 'Die PHP-Erweiterungen iconv und recode, welche fr die Zeichensatzkonvertierung bentigt werden, konnten nicht geladen werden. Bitte ndern Sie Ihre PHP-Konfiguration und aktivieren Sie diese Erweiterungen oder deaktivieren Sie die Zeichensatzkonvertierung in phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Kann Index nicht in PRIMARY umbenennen!';
$strCantUseRecodeIconv = 'Weder die iconv- noch libiconv- oder recode_string-Funktion konnte verwandt werden, obwohl die bentigten php-Erweiterungen angeblich geladen wurden. Bitte berprfen Sie Ihre PHP-Konfiguration.';
$strCardinality = 'Kardinalitt';
$strCaseInsensitive = 'case-insensitive';
$strCaseSensitive = 'case-sensitive';
$strCentralEuropean = 'Mitteleuropisch';
$strChange = 'ndern';
$strChangeCopyModeCopy = ' ... behalte den alten bei.';
$strChangeCopyModeDeleteAndReload = ' ... lsche den alten und lade anschlieend die Benutzertabellen neu.';
$strChangeCopyMode = 'Erstelle einen neuen Benutzer mit identischen Rechten und ...';
$strChangeCopyModeJustDelete = ' ... lsche den alten von den Benutzertabellen.';
$strChangeCopyModeRevoke = ' ... entziehe dem alten alle Rechte und lsche ihn anschlieend.';
$strChangeCopyUser = 'Logininformation ndern / Benutzer kopieren';
$strChangeDisplay = 'Anzuzeigende Spalte bestimmen';
$strChangePassword = 'Kennwort ndern';
$strCharsetOfFile = 'Zeichencodierung der Datei:';
$strCharsetsAndCollations = 'Zeichenstze und Kollationen';
$strCharsets = 'Zeichenstze';
$strCharset = 'Zeichensatz';
$strCheckAll = 'Alle auswhlen';
$strCheckOverhead = 'Tabellen m. berhang ausw.';
$strCheckPrivsLong = 'berprft die Rechte fr die Datenbank &quot;%s&quot;.';
$strCheckPrivs = 'Rechte berprfen';
$strCheckTable = 'berprfe Tabelle';
$strChoosePage = 'Bitte whlen Sie die zu bearbeitende Seite.';
$strColComFeat = 'Darstellung von Spaltenkommentaren';
$strCollation = 'Kollation';
$strColumnNames = 'Spaltennamen';
$strColumnPrivileges = 'Spaltenspezifische Rechte';
$strCommand = 'Befehl';
$strCommentsForTable = 'TABELLENKOMMENTARE';
$strComments = 'Kommentare';
$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
$strCompleteInserts = 'Vollstndige \'INSERT\'s';
$strCompression = 'Kompression';
$strConfigFileError = 'phpMyAdmin konnte Ihre Konfigurationsdatei nicht verarbeiten!<br />Dies kann passieren, wenn der PHP-Parser Syntaxfehler in ihr findet oder sie nicht existiert.<br />Bitte rufen Sie die Konfigurationsdatei ber den unteren Link direkt auf und lesen Sie die PHP-Fehlermeldungen, die Sie erhalten. Meistens fehlt blo irgendwo ein Anfhrungszeichen oder Semikolon.<br />Wenn Sie eine leere Seite erhalten, ist Ihre Konfigurationsdatei in Ordnung.';
$strConfigureTableCoord = 'Bitte konfigurieren Sie die Koordinaten fr die Tabelle %s';
$strConnectionError = 'Die Verbindung konnte aufgrund von ungltigen Einstellungen nicht hergestellt werden.';
$strConnections = 'Verbindungen';
$strConstraintsForDumped = 'Constraints der exportierten Tabellen';
$strConstraintsForTable = 'Constraints der Tabelle';
$strCookiesRequired = 'Ab diesem Punkt mssen Cookies aktiviert sein.';
$strCopyDatabaseOK = 'Datenbank %s wurde nach %s kopiert';
$strCopy = 'Kopieren';
$strCopyTable = 'Kopiere Tabelle nach (Datenbank<b>.</b>Tabellenname):';
$strCopyTableOK = 'Tabelle %s wurde nach %s kopiert.';
$strCopyTableSameNames = 'Tabelle kann nicht mit gleichem Namen kopiert werden!';
$strCouldNotKill = 'phpMyAdmin konnte den Prozess %s nicht abbrechen. Er wurde wahrscheinlich bereits geschlossen.';
$strCreate = 'Anlegen';
$strCreateDatabaseBeforeCopying = 'Vor dem Kopieren CREATE DATABASE ausfhren.';
$strCreateIndex = 'Index ber&nbsp;%s&nbsp;Spalten anlegen';
$strCreateIndexTopic = 'Neuen Index anlegen';
$strCreateNewDatabase = 'Neue Datenbank anlegen';
$strCreateNewTable = 'Neue Tabelle in Datenbank %s erstellen';
$strCreatePage = 'Neue Seite erstellen';
$strCreatePdfFeat = 'Erzeugen von PDFs';
$strCreationDates = 'Erzeugungs- / Aktualisierungs- / berprfungszeiten';
$strCriteria = 'Kriterium';
$strCroatian = 'Kroatisch';
$strCSVOptions = 'CSV-Optionen';
$strCyrillic = 'Kyrillisch';
$strCzechSlovak = 'Tschechoslowakisch';
$strCzech = 'Tschechisch';

$strDanish = 'Dnisch';
$strDatabase = 'Datenbank';
$strDatabaseEmpty = 'Der Datenbankname ist leer!';
$strDatabaseExportOptions = 'Export-Optionen der Datenbank';
$strDatabaseHasBeenDropped = 'Datenbank %s wurde gelscht.';
$strDatabaseNoTable = 'Diese Datenbank enthlt keine Tabelle!';
$strDatabases = 'Datenbanken';
$strDatabasesDropped = 'Es wurden %s Datenbanken gelscht.';
$strDatabasesStatsDisable = 'Datenbankstatistiken deaktivieren';
$strDatabasesStatsEnable = 'Datenbankstatistiken aktivieren';
$strDatabasesStatsHeavyTraffic = 'Bitte beachten Sie: Das Aktivieren der Datenbankstatistiken kann starken Traffic zwischen dem Web- und dem MySQL-Server zur Folge haben.';
$strDatabasesStats = 'Statistik ber alle Datenbanken';
$strData = 'Daten';
$strDataDict = 'Strukturverzeichnis';
$strDataOnly = 'Nur Daten';
$strDataPages = 'Daten enthaltende Seiten';
$strDBComment = 'Datenbankkommentar: ';
$strDBCopy = 'Datenbank kopieren nach';
$strDBGContextID = 'Kontext-ID';
$strDBGContext = 'Kontext';
$strDBGHits = 'Treffer';
$strDBGLine = 'Zeile';
$strDBGMaxTimeMs = 'Max. Zeit in ms';
$strDBGMinTimeMs = 'Min. Zeit in ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'Zeit/Treffer in ms';
$strDBGTotalTimeMs = 'Gesamtzeit in ms';
$strDbPrivileges = 'Datenbankspezifische Rechte';
$strDBRename = 'Datenbank umbenennen in';
$strDbSpecific = 'datenbankspezifisch';
$strDefaultEngine = 'Neue Tabellen werden standardmig im Format %s angelegt.';
$strDefault = 'Standard';
$strDefaultValueHelp = 'Bitte geben Sie jeweils nur einen Standardwert ohne Escape- oder Anfhrungszeichen an.';
$strDefragment = 'Tabelle defragmentieren';
$strDelayedInserts = 'Verzgerten INSERT-Befehl verwenden';
$strDeleteAndFlushDescr = 'Dies ist zwar der sauberste Weg, jedoch kann es einige Zeit in Anspruch nehmen, die Benutzertabellen neu zu laden.';
$strDeleteAndFlush = 'Die Benutzer lschen und die Benutzertabellen anschlieend neu laden.';
$strDeleted = 'Die Zeile wurde gelscht.';
$strDeletedRows = 'Gelschte Zeilen:';
$strDelete = 'Lschen';
$strDeleting = 'Lsche %s';
$strDelOld = 'Auf der aktuellen Seite bestehen Referenzen zu Tabellen, die nicht mehr existieren. Sollen diese Referenzen gelscht werden?';
$strDescending = 'absteigend';
$strDescription = 'Beschreibung';
$strDictionary = 'Wrterbuch';
$strDirtyPages = 'Inkonsistente Seiten (&quot;dirty&quot;)';
$strDisabled = 'Deaktiviert';
$strDisableForeignChecks = 'Fremdschlsselberprfung deaktivieren';
$strDisplayFeat = 'Anzeige verknpfter Daten';
$strDisplayOrder = 'Sortierung nach:';
$strDisplayPDF = 'PDF-Schema anzeigen';
$strDoAQuery = 'Suche ber Beispielwerte ("query by example") (Platzhalter: "%")';
$strDocu = 'Dokumentation';
$strDoYouReally = 'Mchten Sie wirklich diese Abfrage ausfhren ';
$strDropDatabaseStrongWarning = 'Sie sind dabei eine komplette Datenbank zu ZERSTREN!';
$strDrop = 'Lschen';
$strDropSelectedDatabases = 'Ausgewhlte Datenbanken lschen';
$strDropUsersDb = 'Die gleichnamigen Datenbanken lschen.';
$strDumpingData = 'Daten fr Tabelle';
$strDumpSaved = 'Dump (Schema) wurde in Datei %s gespeichert.';
$strDumpXRows = 'Exportiere %s Datenstze ab Zeile %s.';
$strDynamic = 'dynamisch';

$strEdit = 'Bearbeiten';
$strEditPDFPages = 'PDF-Seiten bearbeiten';
$strEditPrivileges = 'Rechte ndern';
$strEffective = 'Effektiv';
$strEmpty = 'Leeren';
$strEmptyResultSet = 'MySQL lieferte ein leeres Resultat zurck (d.h. null Zeilen).';
$strEnabled = 'Aktiviert';
$strEncloseInTransaction = 'Export in einer Transaktion zusammenfassen';
$strEndCut = 'AUSSCHNITTSENDE';
$strEnd = 'Ende';
$strEndRaw = 'ENDE DER AUSGABE';
$strEngineAvailable = '%s ist auf diesem MySQL-Server verfgbar.';
$strEngineDisabled = '%s wurde auf diesem MySQL-Server deaktiviert.';
$strEngines = 'Formate';
$strEngineUnsupported = 'Dieser MySQL-Server untersttzt %s nicht.';
$strEnglish = 'Englisch';
$strEnglishPrivileges = ' Anmerkung: MySQL-Rechte werden auf Englisch angegeben. ';
$strError = 'Fehler';
$strEscapeWildcards = 'Platzhalter _ und % sollten mit einem \ escaped werden, um das gewnschte Sonderzeichen einzubinden';
$strEsperanto = 'Esperanto';
$strEstonian = 'Estnisch';
$strExcelEdition = 'Excel-Ausgabe';
$strExcelOptions = 'Excel-Optionen';
$strExecuteBookmarked = 'Gespeicherte SQL-Anfrage ausfhren';
$strExplain = 'SQL erklren';
$strExport = 'Exportieren';
$strExtendedInserts = 'Erweiterte \'INSERT\'s';
$strExtra = 'Extra';

$strFailedAttempts = 'Fehlgeschlagen';
$strField = 'Feld';
$strFieldHasBeenDropped = 'Spalte %s wurde entfernt.';
$strFieldsEmpty = ' Sie mssen angeben wie viele Felder die Tabelle haben soll! ';
$strFieldsEnclosedBy = 'Felder eingeschlossen von';
$strFieldsEscapedBy = 'Felder escaped von';
$strFields = 'Felder';
$strFieldsTerminatedBy = 'Felder getrennt mit';
$strFileAlreadyExists = 'Die Datei %s besteht bereits auf dem Server. Bitte ndern Sie den Dateinamen oder whlen Sie die berschreibungs-Option.';
$strFileCouldNotBeRead = 'Die Datei konnte nicht gelesen werden';
$strFileNameTemplate = 'Dateinamenskonvention';
$strFileNameTemplateHelp = 'Benutzen Sie __DB__ fr den Datenbanknamen, __TABLE__ fr den Tabellennamen und %sbeliebige strftime-Optionen%s zur Angabe von Datumsvariablen. Die Erweiterung wird automatisch hinzugefgt. Jeglicher anderer Text wird beibehalten.';
$strFileNameTemplateRemember = 'Konvention merken';
$strFixed = 'starr';
$strFlushPrivilegesNote = 'Anmerkung: phpMyAdmin liest die Benutzerprofile direkt aus den entsprechenden MySQL-Tabellen aus. Der Inhalt dieser Tabellen kann sich von den Benutzprofilen, die MySQL z.Zt. verwendet, unterscheiden, wenn manuelle nderungen vorgenommen wurden. In diesem Fall sollten Sie  %sdie Benutzerprofile neu laden%s bevor Sie fortfahren.';
$strFlushTable = 'Leeren des Tabellencaches ("FLUSH")';
$strFormat = 'Format';
$strFormEmpty = 'Das Formular ist leer !';
$strFreePages = 'Unbenutzte Seiten';
$strFullText = 'vollstndige Textfelder';
$strFunction = 'Funktion';

$strGenBy = 'Erstellt von';
$strGeneralRelationFeat = 'Allgemeine Verknpfungsfunktionen';
$strGenerate = 'Generieren';
$strGeneratePassword = 'Passwort generieren';
$strGenTime = 'Erstellungszeit';
$strGeorgian = 'Georgisch';
$strGerman = 'Deutsch';
$strGlobal = 'global';
$strGlobalPrivileges = 'Globale Rechte';
$strGlobalValue = 'Globaler Wert';
$strGo = 'OK';
$strGrantOption = 'Grant';
$strGreek = 'Griechisch';
$strGzip = 'GZip-komprimiert';

$strHasBeenAltered = 'wurde gendert.';
$strHasBeenCreated = 'wurde erzeugt.';
$strHaveToShow = 'Bitte whlen Sie mindestens eine anzuzeigende Spalte';
$strHebrew = 'Hebrisch';
$strHexForBinary = 'Hexadezimalschreibweise fr Binrfelder verwenden';
$strHome = 'Home';
$strHomepageOfficial = ' Offizielle phpMyAdmin-Homepage ';
$strHostEmpty = 'Es wurde kein Host angegeben!';
$strHost = 'Host';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Exportoptionen fr Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Exportoptionen fr Microsoft Word 2000';
$strHungarian = 'Ungarisch';

$strIcelandic = 'Islndisch';
$strId = 'ID';
$strIdxFulltext = 'Volltext';
$strIgnore = 'Ignorieren';
$strIgnoreInserts = 'Fehlerbergehenden INSERT-Befehl verwenden';
$strIgnoringFile = 'Die Datei %s wird ignoriert';
$strImportDocSQL = 'docSQL-Dateien importieren';
$strImportFiles = 'Dateiimport';
$strIndexes = 'Indizes';
$strIndexHasBeenDropped = 'Index %s wurde entfernt.';
$strIndex = 'Index';
$strIndexName = 'Indexname:';
$strIndexType = 'Indextyp:';
$strIndexWarningMultiple = 'Es sollte nicht mehr als ein Index des Typs %s fr die Spalte `%s` gesetzt sein';
$strIndexWarningPrimary = 'Die Index-Typen INDEX und PRIMARY sollten nicht gleichzeitig fr die Spalte `%s` gesetzt sein';
$strIndexWarningTable = 'Warnungen bei den Indizes der Tabelle `%s`';
$strIndexWarningUnique = 'Die Index-Typen INDEX und UNIQUE sollten nicht gleichzeitig fr die Spalte `%s` gesetzt sein';
$strInnoDBAutoextendIncrement = 'Autoerweiterungs-Schrittgre';
$strInnoDBAutoextendIncrementDesc = 'Die Gre, um die ein Tablespace erweitert wird, wenn er voll ist.';
$strInnoDBBufferPoolSizeDesc = 'Die Gre des Arbeitsspeicherpuffers, den InnoDB verwendet, um Daten und Indizes zwischenzuspeichern.';
$strInnoDBBufferPoolSize = 'Gre des Speicherpuffers';
$strInnoDBDataFilePath = 'Datendateien';
$strInnoDBDataHomeDirDesc = 'Der Pfad des Verzeichnisses, unter welchem alle InnoDB-Datendateien abgelegt werden.';
$strInnoDBDataHomeDir = 'Pfad fr Datendateien';
$strInnoDBPages = 'Seiten';
$strInnodbStat = 'InnoDB-Status';
$strInsecureMySQL = 'Ihre Konfigurationsdatei enthlt Einstellungen (Benutzer &quot;root&quot; ohne Passwort), welche denen des MySQL-Standardbenutzers entsprechen. Wird Ihr MySQL-Server mit diesen Einstellungen betrieben, so knnen Unbefugte leicht von auen auf ihn zugreifen. Sie sollten diese Sicherheitslcke unbedingt schlieen!';
$strInsertAsNewRow = ' Als neuen Datensatz speichern ';
$strInsertedRowId = 'Letzte automatisch eingefgte ID:';
$strInsertedRows = 'Eingefgte Zeilen:';
$strInsert = 'Einfgen';
$strInsertNewRow = 'Neue Zeile einfgen';
$strInternalNotNecessary = '* Eine interne Beziehung ist nicht notwendig, wenn sie bereits im InnoDB-Format vorliegt.';
$strInternalRelations = 'Interne Beziehungen';
$strInUse = 'in Benutzung';
$strInvalidFieldAddCount = 'Sie mssen mindestens ein Feld hinzufgen.';

$strJapanese = 'Japanisch';
$strJumpToDB = 'Zur Datenbank &quot;%s&quot; springen.';
$strJustDeleteDescr = 'Die &quot;gelschten&quot; Benutzer knnten weiterhin wie gewohnt auf den Server zugreifen, bis die Benutzertabellen neu geladen werden.';
$strJustDelete = 'Die Benutzer aus den Benutzertabellen lschen.';

$strKeepPass = 'Kennwort nicht verndert';
$strKeyname = 'Name';
$strKill = 'Beenden';
$strKorean = 'Koreanisch';

$strLandscape = 'Querformat';
$strLatchedPages = 'Belegte Seiten';
$strLatexCaption = 'Tabellenbeschriftung';
$strLatexContent = 'Inhalt der Tabelle __TABLE__';
$strLatexContinuedCaption = 'Fortgesetzte Tabellenbeschriftung';
$strLatexContinued = '(Fortsetzung)';
$strLatexIncludeCaption = 'Tabellenbeschriftung einfgen';
$strLatexLabel = 'Kennzeichen';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX-Optionen';
$strLatexStructure = 'Struktur der Tabelle __TABLE__';
$strLatvian = 'Lettisch';
$strLengthSet = 'Lnge/Set';
$strLimitNumRows = 'Eintrge pro Seite';
$strLinesTerminatedBy = 'Zeilen getrennt mit';
$strLinkNotFound = 'Der Verweis wurde nicht gefunden.';
$strLinksTo = 'Verweise';
$strLithuanian = 'Litauisch';
$strLocalhost = 'Lokal';
$strLocationTextfile = 'Datei';
$strLoginInformation = 'Logininformationen';
$strLogin = 'Login';
$strLogout = 'Neu einloggen';
$strLogPassword = 'Kennwort:';
$strLogServer = 'Server';
$strLogUsername = 'Benutzername:';
$strLongOperation = 'Diese Operation knnte einige Zeit beanspruchen. Trotzdem weitermachen?';

$strMaximumSize = 'Maximale Dateigre: %s%s';
$strMbExtensionMissing = 'Die PHP-Erweiterung "mbstring" wurde nicht gefunden, trotzdem jedoch scheinen Sie einen Mehrbyte-Zeichensatz zu verwenden. Ohne besagte Erweiterung ist phpMyAdmin nicht in der Lage Zeichenketten zu trennen, was zu unerwarteten Ergebnissen fhren kann.';
$strMbOverloadWarning = 'Sie haben die Option "mbstring.func_overload" in Ihrer PHP-Konfiguration aktiviert. Diese ist nicht kompatibel zu phpMyAdmin, weshalb es zu Problemen und Datenverlust kommen kann.';
$strMIME_available_mime = 'Verfgbare MIME-Typen';
$strMIME_available_transform = 'Verfgbare Umwandlungen';
$strMIME_description = 'Beschreibung';
$strMIME_MIMEtype = 'MIME-Typ';
$strMIME_nodescription = 'Fr diese Umwandlung ist keine Beschreibung verfgar.<br />Fr weitere Informationen wenden Sie sich bitte an den Autoren der Funktion &quot;%s&quot;.';
$strMIME_transformation = 'Darstellungsumwandlung';
$strMIME_transformation_note = 'Um eine Liste aller verfgbaren MIME-Typen-Umwandlungen und deren Optionen zu sehen, klicken Sie bitte auf %sUmwandlungen%s';
$strMIME_transformation_options_note = 'Bitte die Werte fr die Umwandlungsoptionen in folgendem Format angeben: \'a\',\'b\',\'c\',... Wann immer Sie ein Backslash ("\") oder ein einfaches Anfhrungszeichen ("\'") verwenden, setzen Sie bitte ein Backslash vor das Zeichen. (z. B.: \'\\\\xyz\' oder \'a\\\'b\').';
$strMIME_transformation_options = 'Umwandlungsoptionen';
$strMIMETypesForTable = 'MIME TYPEN DER TABELLE';
$strMIME_without = 'Kursiv dargestellte MIME-Typen besitzen keine untergliederten Umwandlungen.';
$strModifications = 'nderungen gespeichert.';
$strModifyIndexTopic = 'Index modifizieren';
$strModify = 'Verndern';
$strMoveTableOK = 'Tabelle %s wurde nach %s verschoben.';
$strMoveTableSameNames = 'Tabelle kann nicht mit gleichem Namen verschoben werden!';
$strMoveTable = 'Verschiebe Tabelle nach (Datenbank<b>.</b>Tabellenname):';
$strMultilingual = 'multilingual';
$strMyISAMDataPointerSizeDesc = 'Standardmige Gre des Pointers, welcher von CREATE TABLE fr MyISAM-Tabellen verwendet wird, sofern die Option MAX_ROWS nicht angegeben wird.';
$strMyISAMDataPointerSize = 'Gre des Datenpointers';
$strMyISAMMaxExtraSortFileSizeDesc = 'Wenn das Erzeugen der temporren Datei fr schnelle Index-Erzeugung um diesen Wert grer sein wrde als die Benutzung des Schlssel-Caches, wird die Schlssel-Cache-Methode bevorzugt.';
$strMyISAMMaxExtraSortFileSize = 'Maximum Gre temporrer Dateien bei Indexerstellung';
$strMyISAMMaxSortFileSizeDesc = 'Die maximale Gre der temporren Datei, die MySQL benutzen darf, whrend es den Index erzeugt (whrend REPAIR, ALTER TABLE oder LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maximale Gre temporrer Dateien beim Sortieren';
$strMyISAMRecoverOptions = 'Autoreperatur-Modus';
$strMyISAMRecoverOptionsDesc = 'Der Modus der automatischen Wiederherstellung abgestrzter MyISAM-Tabellen, wie ber den Startparameter --myisam-recover angegeben.';
$strMyISAMRepairThreadsDesc = 'Wenn dieser Wert grer als 1 ist, werden MyISAM-Tabellenindizes wrend einer Reperatur oder eines Sortierungsprozesses parallel erstellt (jeder Index in einem separaten Thread).';
$strMyISAMRepairThreads = 'Reperaturthreads';
$strMyISAMSortBufferSizeDesc = 'Der Puffer, der beim Sortieren des Indexes zugewiesen wird, wenn man ein REPAIR oder ausfhrt oder Indizes mit CREATE INDEX oder ALTER TABLE erzeugt.';
$strMyISAMSortBufferSize = 'Gre des Sortierungspuffers';
$strMySQLCharset = 'MySQL-Zeichensatz';
$strMySQLConnectionCollation = 'Zeichensatz / Kollation der MySQL-Verbindung';
$strMySQLReloaded = 'Die MySQL-Benutzertabellen wurden neu geladen.';
$strMySQLSaid = 'MySQL meldet: ';
$strMySQLServerProcess = 'Verbunden mit MySQL %pma_s1% auf %pma_s2% als %pma_s3%';
$strMySQLShowProcess = 'Prozesse anzeigen';
$strMySQLShowStatus = 'MySQL-Laufzeit-Informationen anzeigen';
$strMySQLShowVars = 'MySQL-System-Variablen anzeigen';

$strName = 'Name';
$strNext = 'Nchste';
$strNoActivity = 'Da Sie seit mindestens %s Sekunden inaktiv waren, wurden Sie automatisch abgemeldet. Bitte melden Sie sich erneut an.';
$strNoDatabases = 'Keine Datenbanken';
$strNoDatabasesSelected = 'Es wurden keine Datenbanken ausgewhlt.';
$strNoDescription = 'keine Beschreibung';
$strNoDetailsForEngine = 'Fr dieses Tabellenformat sind keine Statusinformationen verfgbar';
$strNoDropDatabases = 'Die Anweisung "DROP DATABASE" wurde deaktiviert.';
$strNoExplain = 'SQL-Erklrung umgehen';
$strNoFrames = 'phpMyAdmin arbeitet besser mit einem <b>Frame</b>-fhigen Browser.';
$strNoIndex = 'Kein Index definiert!';
$strNoIndexPartsDefined = 'Keine Indizes definiert.';
$strNoModification = 'Keine nderung';
$strNo = 'Nein';
$strNone = 'keine';
$strNoOptions = 'Fr dieses Format sind keine Optionen vorhanden';
$strNoPassword = 'Kein Kennwort';
$strNoPermission = 'Der Webserver hat keine Schreibrechte um die Datei %s zu speichern.';
$strNoPhp = 'ohne PHP-Code';
$strNoPrivileges = 'Keine Rechte';
$strNoRights = 'Sie haben nicht genug Rechte um fortzufahren!';
$strNoRowsSelected = 'Es wurden keine Datenstze ausgewhlt.';
$strNoSpace = 'Zu wenig Speicherplatz um die Datei %s zu speichern.';
$strNoTablesFound = 'Es wurden keine Tabellen in der Datenbank gefunden.';
$strNoThemeSupport = 'Die Untersttzung fr Oberflchendesigns ist deaktiviert. Bitte berprfen Sie Ihre Konfiguration und / oder Ihre Designs im Verzeichnis %s.';
$strNotNumber = 'Das ist keine Zahl!';
$strNotOK = 'fehlerhaft';
$strNotSet = 'Die Tabelle <b>%s</b> wurde entweder nicht gefunden oder in der Kofigurationsdatei %s nicht gesetzt.';
$strNoUsersFound = 'Es wurden keine Benutzer gefunden.';
$strNoValidateSQL = 'SQL-Validierung umgehen';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s Treffer in der Tabelle <i>%s</i>';
$strNumSearchResultsTotal = '<b>Insgesamt</b> <i>%s</i> Treffer';
$strNumTables = 'Tabellen';

$strOK = 'OK';
$strOperations = 'Operationen';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimiere Tabelle';
$strOr = 'oder';
$strOverhead = 'berhang';
$strOverwriteExisting = 'Bestehende Datei(en) berschreiben';

$strPageNumber = 'Seite:';
$strPagesToBeFlushed = 'Zurckzuschreibende Seiten';
$strPaperSize = 'Papiergre';
$strPartialText = 'gekrzte Textfelder';
$strPasswordChanged = 'Das Kennwort fr %s wurde gendert.';
$strPasswordEmpty = 'Es wurde kein Kennwort angegeben!';
$strPasswordHashing = 'Password-Verschlsselung';
$strPassword = 'Kennwort';
$strPasswordNotSame = 'Die eingegebenen Kennwrter sind nicht identisch!';
$strPdfDbSchema = 'Schema der Datenbank "%s" - Seite %s';
$strPdfInvalidTblName = 'Die Tabelle "%s" existiert nicht!';
$strPdfNoTables = 'keine Tabellen';
$strPerHour = 'pro Stunde';
$strPerMinute = 'pro Minute';
$strPerSecond = 'pro Sekunde';
$strPersian = 'Persisch';
$strPhoneBook = 'Telefonbuch';
$strPHP40203 = 'Sie verwenden die PHP-Version 4.2.3, welche leider fehlerhaft im Umgang mit Multibyte-Zeichenketten (mbstring) ist. Dieser Fehler ist in der PHP-Datenbank als Bug-Report #19404 dokumentiert. Aus diesem Grund wird diese PHP-Version nicht fr den Betrieb von phpMyAdmin empfohlen.';
$strPhp = 'PHP-Code erzeugen';
$strPHPVersion = 'PHP-Version';
$strPmaDocumentation = 'phpMyAdmin-Dokumentation';
$strPmaUriError = 'Das <tt>$cfg[\'PmaAbsoluteUri\']</tt>-Verzeichnis MUSS in Ihrer Konfigurationsdatei angegeben werden!';
$strPolish = 'Polnisch';
$strPortrait = 'Hochformat';
$strPos1 = 'Anfang';
$strPrevious = 'Vorherige';
$strPrimaryKeyHasBeenDropped = 'Der Primrschlssel wurde gelscht.';
$strPrimaryKeyName = 'Der Name des Primrschlssels muss PRIMARY lauten!';
$strPrimaryKeyWarning = 'Der Name des Primrschlssels darf <b>nur</b> "PRIMARY" lauten.';
$strPrimary = 'Primrschlssel';
$strPrint = 'Drucken';
$strPrintView = 'Druckansicht';
$strPrintViewFull = 'Druckansicht (vollstndige Textfelder)';
$strPrivDescAllPrivileges = 'Enthlt alle Rechte bis auf GRANT.';
$strPrivDescAlter = 'Erlaubt das Verndern der Struktur bestehender Tabellen.';
$strPrivDescCreateDb = 'Erlaubt das Erstellen neuer Datenbanken und Tabellen.';
$strPrivDescCreateTbl = 'Erlaubt das Erstellen neuer Tabellen.';
$strPrivDescCreateTmpTable = 'Erlaubt das Erstellen temporrer Tabellen.';
$strPrivDescDelete = 'Erlaubt das Lschen von Daten.';
$strPrivDescDropDb = 'Erlaubt das Lschen ganzer Datenbanken und Tabellen.';
$strPrivDescDropTbl = 'Erlaubt das Lschen ganzer Tabellen.';
$strPrivDescExecute = 'Erlaubt das Ausfhren gespeicherter Prozeduren; Hat keinen Effekt in dieser MySQL-Version.';
$strPrivDescFile = 'Erlaubt das Importieren von Daten aus und das Exportieren in externe Dateien.';
$strPrivDescGrant = 'Erlaubt das Hinzufgen von Benutzern und Rechten ohne den die Benutzerprofile neu laden zu mssen.';
$strPrivDescIndex = 'Erlaubt das Erstellen und Lschen von Indizes.';
$strPrivDescInsert = 'Erlaubt das Hinzufgen und Ersetzen von Daten.';
$strPrivDescLockTables = 'Erlaubt die Sperrung bestimmter Tabellen.';
$strPrivDescMaxConnections = 'Begrenzt die Anzahl neuer Verbindungen, welche ein Benutzer pro Stunde aufbauen darf.';
$strPrivDescMaxQuestions = 'Begrenzt die Anzahl der Abfragen, welche ein Benutzer pro Stunde senden darf.';
$strPrivDescMaxUpdates = 'Begrenzt die Anzahl der Vernderungen, welche ein Benutzer pro Stunde an allen Datenbanken und Tabellen vornehmen darf.';
$strPrivDescProcess3 = 'Erlaubt das Beenden fremder Prozesse.';
$strPrivDescProcess4 = 'Erlaubt das Anzeigen der vollen Abfragen in der Prozessliste.';
$strPrivDescReferences = 'Hat keinen Effekt in dieser MySQL-Version.';
$strPrivDescReload = 'Erlaubt das erneute Laden von Servereinstellungen und das Leeren der Zwischenspeicher zur Laufzeit.';
$strPrivDescReplClient = 'Erlaubt dem Benutzer zu fragen, wo sich die Master- bzw. Slave-Systeme befinden';
$strPrivDescReplSlave = 'Wird fr die Replication-Slave-Systeme bentigt.';
$strPrivDescSelect = 'Erlaubt das Auslesen von Daten.';
$strPrivDescShowDb = 'Gewhrt Zugang zur vollstndigen Datenbankliste.';
$strPrivDescShutdown = 'Erlaubt das Beenden des Servers.';
$strPrivDescSuper = 'Erlaubt eine Verbindung, selbst wenn die maximale Anzahl an Verbindungen bereits erreicht ist; Wird fr viele administrative Operationen, wie das Setzen globaler Variables oder das Beenden fremder Prozesse, vorausgesetzt.';
$strPrivDescUpdate = 'Erlaubt das Verndern von gespeicherten Daten.';
$strPrivDescUsage = 'Keine Rechte.';
$strPrivileges = 'Rechte';
$strPrivilegesReloaded = 'Die Benutzerprofile wurden neu geladen.';
$strProcesslist = 'Prozesse';
$strPutColNames = 'Feldnamen in die erste Zeile setzen';

$strQBE = 'Abfrageeditor';
$strQBEDel = 'Entf.';
$strQBEIns = 'Einf.';
$strQueryFrame = 'Abfragefenster';
$strQueryOnDb = ' SQL-Befehl in der Datenbank <b>%s</b>:';
$strQuerySQLHistory = 'SQL-Verlaufsprotokoll';
$strQueryStatistics = '<b>Abfragestatistik</b>: Seit seinem Start wurden %s Abfragen an diesen MySQL-Server gesandt.';
$strQueryTime = 'die Abfrage dauerte %01.4f sek';
$strQueryType = 'Abfrageart';
$strQueryWindowLock = 'Abfrage vor nderungen auerhalb des Fensters schtzen';

$strReadRequests = 'Leseanfragen';
$strReceived = 'Empfangen';
$strRecords = 'Eintrge';
$strReferentialIntegrity = 'Prfe referentielle Integritt:';
$strRefresh = 'Aktualisieren';
$strRelationalSchema = 'Beziehungsschema';
$strRelationNotWorking = 'Die zustzlichen Funktionen fr verknpfte Tabellen wurden automatisch deaktiviert. Klicken Sie %shier%s um herauszufinden warum.';
$strRelationsForTable = 'RELATIONEN DER TABELLE';
$strRelations = 'Tabellenverknpfungen';
$strRelationView = 'Beziehungsbersicht';
$strReloadFailed = 'MySQL Neuladen fehlgeschlagen.';
$strReloadingThePrivileges = 'Lade die Benutzertabellen neu';
$strReloadMySQL = 'Benutzertabellen neu laden';
$strRemoveSelectedUsers = 'Die ausgewhlten Benutzer lschen';
$strRenameDatabaseOK = 'Datenbank %s wurde umbenannt zu %s';
$strRenameTableOK = 'Tabelle %s wurde umbenannt in %s.';
$strRenameTable = 'Tabelle umbenennen in';
$strRepairTable = 'Repariere Tabelle';
$strReplaceNULLBy = 'Ersetze NULL durch';
$strReplaceTable = 'Tabelleninhalt ersetzen';
$strReset = 'Zurcksetzen';
$strResourceLimits = 'Ressourcenbeschrnkungen';
$strReType = 'Wiederholen';
$strRevokeAndDelete = 'Den Benutzern alle Rechte entziehen und sie anschlieend aus den Benutzertabellen lschen.';
$strRevokeAndDeleteDescr = 'Die Benutzer wrden weiterhin das USAGE-Recht behalten, bis die Benutzertabellen neu geladen werden.';
$strRevoke = 'Entfernen';
$strRevokeMessage = 'Sie haben die Rechte fr %s entfernt.';
$strRomanian = 'Rumnisch';
$strRowLength = 'Zeilenlnge';
$strRowsFrom = 'Datenstze, beginnend ab';
$strRowSize = 'Zeilengre';
$strRowsModeFlippedHorizontal = 'horizontal (gedrehte Bezeichner)';
$strRowsModeHorizontal = 'untereinander';
$strRowsModeOptions = '%s angeordnet und wiederhole die Kopfzeilen nach %s Datenstzen.';
$strRowsModeVertical = 'nebeneinander';
$strRowsStatistic = 'Zeilenstatistik';
$strRows = 'Zeilen';
$strRunning = 'auf %s';
$strRunQuery = 'SQL-Befehl ausfhren';
$strRunSQLQuery = 'SQL-Befehl(e) in Datenbank %s ausfhren';
$strRussian = 'Russisch';

$strSaveOnServer = 'Datei auf dem Server in Verzeichnis %s speichern';
$strSave = 'Speichern';
$strScaleFactorSmall = 'Der Skalierungsfaktor ist zu klein, sodass das Schema nicht auf eine Seite passt!';
$strSearchFormTitle = 'Durchsuche die Datenbank';
$strSearchInTables = 'In der / den Tabelle(n):';
$strSearchNeedle = 'Zu suchende Wrter oder Werte (Platzhalter: "%"):';
$strSearchOption1 = 'mindestens eines der Wrter';
$strSearchOption2 = 'alle Wrter';
$strSearchOption3 = 'genau diese Zeichenkette';
$strSearchOption4 = 'als regulren Ausdruck';
$strSearchResultsFor = 'Suchergebnisse fr "<i>%s</i>" %s:';
$strSearch = 'Suche';
$strSearchType = 'Finde:';
$strSecretRequired = 'Ab sofort muss ein geheimes Passwort zur Verschlsselung in der Konfigurationsdatei gesetzt werden (blowfish_secret).';
$strSelectADb = 'Bitte Datenbank auswhlen';
$strSelectAll = 'Alle auswhlen';
$strSelectBinaryLog = 'Binre Protokolldatei zur Anzeige auswhlen';
$strSelectFields = 'Felder auswhlen (mind. eines):';
$strSelectNumRows = 'in der Abfrage';
$strSelectTables = 'Tabellenauswahl';
$strSend = 'Senden';
$strSent = 'Gesendet';
$strServerChoice = 'Server Auswhlen';
$strServerNotResponding = 'Der Server antwortet nicht.';
$strServer = 'Server';
$strServerStatus = 'Laufzeit-Informationen';
$strServerStatusUptime = 'Dieser MySQL-Server luft bereits %s. Er wurde am %s gestartet.';
$strServerTabProcesslist = 'Prozesse';
$strServerTabVariables = 'Variablen';
$strServerTrafficNotes = '<b>Servertraffic</b>: In diesen Tabellen wird der Netzwerktraffic dieses MySQL-Servers seit dessen Start aufgefhrt.';
$strServerVars = 'Servervariablen und -einstellungen';
$strServerVersion = 'Server Version';
$strSessionValue = 'Wert fr diese Sitzung';
$strSetEnumVal = 'Wenn das Feld vom Typ \'ENUM\' oder \'SET\' ist, benutzen Sie bitte das Format: \'a\',\'b\',\'c\',... Wann immer Sie ein Backslash ("\") oder ein einfaches Anfhrungszeichen ("\'") verwenden, setzen Sie bitte ein Backslash vor das Zeichen. (z. B.: \'\\\\xyz\' oder \'a\\\'b\').';
$strShowAll = 'Alles anzeigen';
$strShowColor = 'mehrfarbig';
$strShowDatadictAs = 'Format des Strukturverzeichnisses';
$strShowFullQueries = 'Zeige die SQL-Abfragen vollstndig an';
$strShowGrid = 'Gitterlinien anzeigen';
$strShowingRecords = 'Zeige Datenstze ';
$strShowPHPInfo = 'PHP-Informationen anzeigen';
$strShowTableDimension = 'Tabellendimensionen anzeigen.';
$strShowTables = 'Tabellen anzeigen';
$strShowThisQuery = 'SQL-Befehl hier wieder anzeigen';
$strShow = 'Zeige';
$strSimplifiedChinese = 'Vereinfachtes Chinesisch';
$strSingly = '(einmalig)';
$strSize = 'Gre';
$strSlovak = 'Slovakisch';
$strSlovenian = 'Slovenisch';
$strSocketProblem = '(evtl. ist auch der Socket des lokalen MySQL-Servers socket nicht korrekt konfiguriert)';
$strSortByKey = 'Nach Schlssel sortieren';
$strSort = 'Sortierung';
$strSpaceUsage = 'Speicherplatzverbrauch';
$strSpanish = 'Spanisch';
$strSplitWordsWithSpace = 'Die Wrter werden durch Leerzeichen (" ") getrennt.';
$strSQLExportCompatibility = 'SQL-Export-Kompatibilitt';
$strSQLExportType = 'Exporttyp';
$strSQLOptions = 'SQL-Optionen';
$strSQLParserBugMessage = 'Mglicherweise haben Sie einen Bug im SQL-Parser entdeckt. Bitte berprfen Sie Ihre Abfrage genaustens, insbesondere auf falsch gesetzte oder nicht geschlossene Anfhrungszeichen. Eine weitere Ursache knnte darin liegen, dass Sie versuchen eine Datei mit binren Daten, welche nicht von Anfhrungszeichen eingeschlossen sind, hochzuladen. Sie knnen alternativ versuchen Ihre Abfrage ber das MySQL-Kommandozeileninterface zu senden. Die MySQL-Fehlerausgabe, falls vorhanden, kann Ihnen auch bei der Fehleranalyse helfen. Falls Sie weiterhin Probleme haben sollten oder der Parser dort versagt, wo die Kommandozeile erfolgreich ist, so reduzieren Sie bitte Ihre Abfrage auf den Befehl, welcher die Probleme verursacht, und senden Sie uns einen Bugreport mit den Datenausschnitt, den Sie weiter unten auf dieser Seite finden.:';
$strSQLParserUserError = 'Es scheint einen Fehler in Ihrer MySQL-Abfrage zu geben. Die MySQL-Fehlerausgabe, falls vorhanden, kann Ihnen auch bei der Fehleranalyse helfen.';
$strSQLQuery = 'SQL-Befehl';
$strSQLResult = 'SQL-Abfrageergebnis';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Ungltiger Bezeichner';
$strSQPBugUnclosedQuote = 'Nicht geschlossene Anfhrungszeichen';
$strSQPBugUnknownPunctuation = 'Unbekannte Interpunktion';
$strStatCheckTime = 'Letzter Check am';
$strStatCreateTime = 'Erzeugt am';
$strStatement = 'Angaben';
$strStatUpdateTime = 'Aktualisiert am';
$strStatus = 'Status';
$strStorageEngines = 'Tabellenformate';
$strStorageEngine = 'Tabellenformat';
$strStrucCSV = 'CSV-Daten';
$strStrucData = 'Struktur und Daten';
$strStrucDrop = 'Mit \'DROP TABLE\'';
$strStrucExcelCSV = 'CSV-Daten fr MS Excel';
$strStrucNativeExcel = 'Excel-Datei';
$strStrucOnly = 'Nur Struktur';
$strStructPropose = 'Tabellenstruktur analysieren';
$strStructure = 'Struktur';
$strSubmit = 'Abschicken';
$strSuccess = 'Ihr SQL-Befehl wurde erfolgreich ausgefhrt.';
$strSum = 'Gesamt';
$strSwedish = 'Schwedisch';
$strSwitchToDatabase = 'Zu kopierter Datenbank wechseln';
$strSwitchToTable = 'Zur kopierten Tabelle wechseln';

$strTableComments = 'Tabellen-Kommentar';
$strTableEmpty = 'Der Tabellenname ist leer!';
$strTableHasBeenDropped = 'Die Tabelle %s wurde gelscht.';
$strTableHasBeenEmptied = 'Die Tabelle %s wurde geleert.';
$strTableHasBeenFlushed = 'Die Tabelle %s wurde geschlossen und zwischengespeicherte Daten gespeichert.';
$strTableMaintenance = 'Hilfsmittel';
$strTableOfContents = 'Inhalt';
$strTableOptions = 'Tabellenoptionen';
$strTables = '%s Tabellen';
$strTableStructure = 'Tabellenstruktur fr Tabelle';
$strTable = 'Tabelle';
$strTableType = 'Tabellentyp';
$strTakeIt = 'auswhlen';
$strTblPrivileges = 'Tabellenspezifische Rechte';
$strTextAreaLength = 'Wegen seiner Lnge ist dieses<br />Feld vielleicht nicht editierbar.';
$strThai = 'Thai';
$strTheme = 'Oberflchendesign';
$strThisHost = 'Dieser Host';
$strThisNotDirectory = 'Dies ist kein Verzeichnis';
$strThreadSuccessfullyKilled = 'Der Prozess %s wurde erfolgreich abgebrochen.';
$strTime = 'Dauer';
$strToggleScratchboard = 'Klemmbrett anzeigen';
$strTotal = 'insgesamt';
$strTotalUC = 'Insgesamt';
$strTraditionalChinese = 'Traditionelles Chinesisch';
$strTraditionalSpanish = 'Traditionelles Spanisch';
$strTraffic = 'Traffic';
$strTransformation_application_octetstream__download = 'Zeigt einen Link an, um die binren Daten eines Feldes downloaden zu knnen. Die erste Option benennt den Dateinamen. Die zweite Option kann einen Spaltennamen der Tabelle benennen, aus dem der Dateiname geholt werden soll. Sollte die zweite Option gesetzt sein ist es notwendig, die erste Option auf einen Leerstring zu setzen (\'\')';
$strTransformation_image_jpeg__inline = 'Ein klickbares Vorschaubild anzeigen. Optionen: Breite, Hhe in Pixeln (bercksichtigt Seitenverhltnis)';
$strTransformation_image_jpeg__link = 'Einen Link zum Bild anzeigen, z.B. zum Download von BLOB-Daten.';
$strTransformation_image_png__inline = 'Siehe image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Wandelt ein TIME, TIMESTAMP oder DATETIME-Feld und formatiert es unter Bercksichtigung des lokalen Zeitformats. Erste Option: Differenz (in Stunden) zur Addition/Subtraktion der aktuellen Zeit (Standard: 0). Zweite Option: Zeitformat anstelle des lokalen, Variablen siehe PHPs strftime().';
$strTransformation_text_plain__external = 'Nur fr LINUX: Startet ein externes Programm und verwendet die Daten des Feldes fr die Standardeingabe. Stellt innerhalb von phpMyAdmin die Standardausgabe des externen Programmes dar. Die Voreinstellung wurde fr Tidy optimiert, um HTML code optisch zu formatieren. Aus Sicherheitsgrnden mssen Sie die Datei libraries/transformations/text_plain__external.inc.php von Hand bearbeiten um weitere Programme hinzuzufgen. Die erste Option ist die Nummer des dort hinterlegten Programmes und die zweite Option legt die Parameter fr das externe Programm fest. Die dritte Option bestimmt, falls auf 1 gesetzt, dass die Ausgabe mit htmlspecialchars() formatiert wird (Standard: 1). Die vierte Option bestimmt, falls auf 1 gesetzt, ob ein NOWRAP-Parameter der Tabellenzelle hinzugefgt wird um einen automatischen Umbruch der Standardausgabe zu verhindern (Standard: 1)';
$strTransformation_text_plain__formatted = 'Behlt Ursprungsformatierung des Feldes bei. Kein Escaping oder Umlautwandlung wird durchgefhrt.';
$strTransformation_text_plain__imagelink = 'Benutzt den Inhalt eines Feldes um ein Bild und einen Link dazu darzustellen. Die erste Option ist ein Prfix vor dem eigentlichen Feldinhalt wie "http://www.domain.com". Zweite Option ist die Breite des Bildes, die dritte Option die Hhe des Bildes in Pixeln.';
$strTransformation_text_plain__link = 'Benutzt den Inhalt eines Feldes um einen Link darzustellen. Die erste Option ist ein Prfix vor dem eigentlichen Feldinhalt wie "http://www.domain.com". Zweite Option ist der darzustellende Titel des Links';
$strTransformation_text_plain__substr = 'Stellt nur einen Teil des Feldinhaltes dar. Die erste Option definiert die Position des Textes ab dem die Ausgabe startet (Standard: 0), die zweite Option gibt an wieviel Zeichen ab dort dargestellt werden sollen. Falls diese Option leer ist, wird der gesamte verbleibende Text dargestellt. Die dritte Option kann einen Text enthalten, der bei partieller Ausgabe des Textes angehngt wird, um eine Abschneidung kenntlich zu machen (Standard: ...).';
$strTruncateQueries = 'Zeige die SQL-Abfragen verkrzt an';
$strTurkish = 'Trkisch';
$strType = 'Typ';

$strUkrainian = 'Ukrainisch';
$strUncheckAll = 'Auswahl entfernen';
$strUnicode = 'Unicode';
$strUnique = 'Unique';
$strUnknown = 'unbekannt';
$strUnselectAll = 'Auswahl entfernen';
$strUnsupportedCompressionDetected = 'Sie haben versucht, eine Datei zu laden, die mit einem nicht untersttzten Verfahren komprimiert wurde (%s). Entweder ist die Untersttzung fr selbiges nicht implementiert oder in IHrer Konfiguration deaktiviert.';
$strUpdatePrivMessage = 'Die Rechte fr %s wurden gendert.';
$strUpdateProfileMessage = 'Benutzer wurde gendert.';
$strUpdateQuery = 'Aktualisieren';
$strUpdComTab = 'Bitte lesen Sie in der Dokumentation nach, wie Sie die Struktur Ihrer Spaltenkommentartabelle aktualisieren knnen';
$strUpgrade = 'Sie sollten auf %s %s oder neuer umsteigen.';
$strUsage = 'Verbrauch';
$strUseBackquotes = ' Tabellen- und Feldnamen in einfachen Anfhrungszeichen ';
$strUseHostTable = 'Verwende Hosttabelle';
$strUserAlreadyExists = 'Der Benutzer %s existiert bereits!';
$strUser = 'Benutzer';
$strUserEmpty = 'Kein Benutzername eingegeben!';
$strUserName = 'Benutzername';
$strUserNotFound = 'Der gewhlte Benutzer wurde in der Benutzertabelle nicht gefunden.';
$strUserOverview = 'Benutzerbersicht';
$strUsersDeleted = 'Die gewhlten Benutzer wurden gelscht.';
$strUsersHavingAccessToDb = 'Benutzer mit Zugriff auf &quot;%s&quot;';
$strUseTabKey = 'Mittels TAB-Taste von Feld zu Feld springen, oder mit STRG+Pfeiltasten beliebig bewegen';
$strUseTables = 'Verwendete Tabellen';
$strUseTextField = 'Textfeld verwenden';
$strUseThisValue = 'Diesen Wert verwenden';

$strValidateSQL = 'SQL validieren';
$strValidatorError = 'Bei der Initialisierung des SQL-Validators ist ein Fehler aufgetreten. Bitte berprfen Sie, ob Sie die in der %sDokumentation%s beschriebenen php-Erweiterungen installiert haben.';
$strValue = 'Wert';
$strVar = 'Variable';
$strVersionInformation = 'Versionsinformationen';
$strView = 'Ansicht';
$strViewDumpDatabases = 'Dump (Schema) der Datenbanken anzeigen';
$strViewDumpDB = 'Dump (Schema) der Datenbank anzeigen';
$strViewDump = 'Dump (Schema) der Tabelle anzeigen';
$strViewHasBeenDropped = 'Die Ansicht %s wurde gelscht';

$strWebServerUploadDirectoryError = 'Auf das festgelegte Upload-Verzeichnis kann nicht zugegriffen werden.';
$strWebServerUploadDirectory = 'Upload-Verzeichnis auf dem Webserver';
$strWelcome = 'Willkommen bei %s';
$strWestEuropean = 'Westeuropisch';
$strWildcard = 'Platzhalter';
$strWindowNotFound = 'Das Ziel-Browserfenster konnte nicht aktualisiert werden. Mglicherweise wurde das Ursprungsfenster geschlossen oder der Browser verhindert den Zugriff aufgrund von Ihren Sicherheitseinstellungen.';
$strWithChecked = 'markierte:';
$strWriteRequests = 'Schreibanfragen';
$strWritingCommentNotPossible = 'Es knnen keine Kommentare geschrieben werden';
$strWritingRelationNotPossible = 'Es knnen keine Spaltenbeziehungen gespeichert werden.';
$strWrongUser = 'Falscher Benutzername/Kennwort. Zugriff verweigert.';

$strXML = 'XML';

$strYes = 'Ja';

$strZeroRemovesTheLimit = 'Anmerkung: Der Wert 0 (null) entfernt die Beschrnkung.';
$strZip = 'Zip-komprimiert';

// To translate:
$strAllowInterrupt = 'Abbruch wenn die maximale Scriptlaufzeit errreicht wird. Damit ist es mglich groe Dateien zu importieren, allerdings kann es Transaktionen zerstren.';  //recently translated
$strAndThen = 'and then';  //to translate

$strBookmarkCreated = 'Bookmark %s gespeichert';  //recently translated
$strBookmarkReplace = 'berschreibe gleichnamiges Bookmark';  //recently translated

$strCompressionWillBeDetected = 'Dateikomprimierung wird automatisch erkannt bei: %s';  //recently translated
$strCSV = 'CSV';  //recently translated
$strCSVImportOptions = 'CSV Optionen';  //recently translated

$strDeleteNoUsersSelected = 'Keine Benutzer zum Lschen ausgewhlt!';  //recently translated

$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
$strErrorInZipFile = 'Fehler im ZIP-Archive:';  //recently translated

$strFileToImport = 'Datei zum Importieren';  //recently translated
$strFlushQueryCache = 'Schreibe/Leere den Abfrage-Cache ("FLUSH")';  //recently translated
$strFlushTables = 'Leeren des gesamten Tabellencaches ("FLUSH")';  //recently translated

$strHandler = 'Handler';  //recently translated

$strIgnoreDuplicates = 'Ignoriere doppelte Zeilen';  //recently translated
$strImportFinished = 'Der Import wurde erfolgreich beendet.';  //recently translated
$strImportFormat = 'Dateiformat';  //recently translated
$strImport = 'Importieren';  //recently translated
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strInvalidColumnCount = 'Die Spaltenanzahl muss grer als 0 sein.';  //recently translated
$strInvalidColumn = 'Ungltige Spalte (%s) angegeben!';  //recently translated
$strInvalidCSVInput = 'Ungltige CSV Daten, verarbeitung nicht mglich!';  //recently translated
$strInvalidFieldCount = 'Die Tabelle muss mindestens ein Feld haben.';  //recently translated
$strInvalidLDIImport = 'Dieses Plugin untersttzt keine Komprimierung!';  //recently translated
$strInvalidRowNumber = '%d ist keine gltige Zeilennummer.';  //recently translated

$strJoins = 'Tabellenverknpfungen (joins)';  //recently translated

$strKeyCache = 'Schlssel-Cache';  //recently translated

$strLDI = 'CSV mit LOAD DATA';  //recently translated
$strLDIImportOptions = 'Optionen fr den CSV-Import mit LOAD DATA';  //recently translated
$strLDILocal = 'mit LOCAL';  //recently translated

$strMaxConnects = 'max. gleichzeitige Verbindungen';  //recently translated
$strMaximalQueryLength = 'Maximale Lnge der erstellten Abfrage';  //recently translated

$strNoFilesFoundInZip = 'Keine Dateien im ZIP-Archive gefunden!';  //recently translated
$strNothingToImport = 'Keine Daten zum importieren gefunden!';  //recently translated
$strNumberOfFields = 'Anzahl der Felder';  //recently translated

$strPartialImport = 'Teilweiser Import';  //recently translated
$strPrivDescAlterRoutine = 'Erlaubt das Verndern und Lschen von gespeicherten Prozeduren (stored procedures).';  //recently translated
$strPrivDescCreateRoutine = 'Erlaubt das Erstellen von gespeicherten Prozeduren (stored procedures).';  //recently translated
$strPrivDescCreateUser = 'Erlaubt das Erstellen, Lschen und Umbenennen von Benutzern.';  //recently translated
$strPrivDescCreateView = 'Erlaubt das Erstellen von Ansichten (views).';  //recently translated
$strPrivDescExecute5 = 'Erlaubt das Ausfhren von gespeicherten Prozeduren (stored procedures).';  //recently translated
$strPrivDescMaxUserConnections = 'Beschrnkt die Anzahl der gleichzeitigen Verbindungen fr diesen Benutzer.';  //recently translated
$strPrivDescShowView = 'Erlaubt das Abfragen von \'SHOW CREATE VIEW\'.';  //recently translated

$strQueryCache = 'Abfrage-Cache';  //recently translated

$strReplication = 'Replikation';  //recently translated
$strRunSQLQueryOnServer = 'SQL-Befehl(e) auf Server %s ausfhren';  //recently translated

$strServerStatusDelayedInserts = 'Verzgertes Einfgen (delayed inserts)';  //recently translated
$strShowingBookmark = 'Showing bookmark';  //to translate
$strShowOpenTables = 'Zeige alle offenen Tabellen';  //recently translated
$strShowSlaveHosts = 'Zeige alle Slave-Rechner';  //recently translated
$strShowSlaveStatus = 'Zeige den Slave-Status';  //recently translated
$strShowStatusBinlog_cache_disk_useDescr = 'Anzahl der Transaktionen die den Binrylog-Cache verwendet haben aber die Gre des Binarylog-Caches (binlog_cache_size) berschritten haben und eine temporre Datei verwendet haben um die [statements] der Transaktion zu speichern.';  //recently translated
$strShowStatusBinlog_cache_useDescr = 'Anzahl der Transaktionen, die den temporren Binarylog-Cache verwendet haben.';  //recently translated
$strShowStatusCreated_tmp_disk_tablesDescr = 'Anzahl der (implizit) auf der Platte erzeugten temporren Tabellen bei der Ausfhrung von Statements. Wenn Created_tmp_disk_tables hoch ist, sollten Sie eventuell die tmp_table_size-Variable herauf setzen, damit temporre Tabellen im Speicher erzeugt werden statt auf der Platte.';  //recently translated
$strShowStatusCreated_tmp_filesDescr = 'Wieviele temporre Dateien mysqld erzeugt hat.';  //recently translated
$strShowStatusCreated_tmp_tablesDescr = 'Anzahl der (implizit) im Arbeitsspeicher erzeugten temporren Tabellen bei der Ausfhrung von Statements.';  //recently translated
$strShowStatusDelayed_errorsDescr = 'Anzahl der Zeilen, die mit INSERT DELAYED geschrieben wurden, und bei denen irgend ein Fehler auftrat (wahrscheinlich duplicate key).';  //recently translated
$strShowStatusDelayed_insert_threadsDescr = 'Anzahl der verzgerten Insert-Handler-Threads in Benutzung. Jede einzelne Tabelle mit verzgerten Inserts bekommt einen eigenen Thread.';  //recently translated
$strShowStatusDelayed_writesDescr = 'Anzahl der Zeilen, die mit INSERT DELAYED geschrieben wurden.';  //recently translated
$strShowStatusFlush_commandsDescr  = 'Anzahl der ausgefhrten FLUSH-Befehle.';  //recently translated
$strShowStatusHandler_commitDescr = 'Anzahl der Anfragen, ein COMMIT auszufhren.';  //recently translated
$strShowStatusHandler_deleteDescr = 'Wie oft eine Zeile aus einer Tabelle gelscht wurde.';  //recently translated
$strShowStatusHandler_discoverDescr = 'Anzahl der gesuchten und gefundenen (discovered) Tabellen. Der MySQL-Server kann das NDB-Cluster-Storage-Engine fragen ob es eine bestimmte Tabelle kennt. Dieser Vorgang wird \'discovery\' genannt.';  //recently translated
$strShowStatusHandler_read_firstDescr = 'Wie oft der erste Eintrag aus einem Index gelesen wurde. Wenn dieser Wert hoch ist, legt das nahe, dass der Server viele komplette Index-Scans macht (zum Beispiel SELECT spalte1 FROM foo, unter der Annahme, dass spalte1 indiziert ist).';  //recently translated
$strShowStatusHandler_read_keyDescr = 'Anzahl der Anfragen, eine Zeile basierend auf einem Schlssel zu lesen. Wenn dieser Wert hoch ist, ist das ein gutes Indiz dafr, dass Ihre Anfragen und Tabellen korrekt indiziert sind.';  //recently translated
$strShowStatusHandler_read_nextDescr = 'Anzahl der Anfragen, die nchste Zeile in der Reihenfolge des Schlssels zu lesen. Dieser Wert wird herauf gezhlt, wenn Sie eine Index-Spalte mit einer Bereichsbeschrnkung (Limit) abfragen. Er wird ebenfalls herauf gezhlt, wenn Sie einen Index-Scan durchfhren.';  //recently translated
$strShowStatusHandler_read_prevDescr = 'Anzahl der Anfragen, die vorhergehende Zeile in der Reihenfolge des Schlssels zu lesen. Diese Lese-Methode ist hauptschlich zur Optimierung von ORDER BY ... DESC.';  //recently translated
$strShowStatusHandler_read_rndDescr = 'Anzahl der Anfragen, eine Zeile basierend auf einer festen Position zu lesen. Dieser Wert wird hoch sein, wenn Sie viele Anfragen ausfhren, die erfordern, dass das Ergebnis sortiert wird. Wenn Handler_read_rnd hoch ist, haben Sie wahrscheinlich viele Anfragen, die MySQL zwingen, ganze Tabellen zu scannen, oder Sie haben Joins, die Schlssel nicht richtig benutzen.';  //recently translated
$strShowStatusHandler_read_rnd_nextDescr = 'Anzahl der Anfragen, die nchste Zeile in der Daten-Datei zu lesen. Dieser Wert wird hoch sein, wenn Sie viele Tabellen-Scans durchfhren. Im Allgemeinen weist das darauf hin, dass Ihre Tabellen nicht korrekt indiziert sind, oder dass Ihre Anfragen nicht so geschrieben sind, dass Sie Vorteile aus den Indexen ziehen, die Sie haben.';  //recently translated
$strShowStatusHandler_rollbackDescr = 'Anzahl der Anfragen, ein ROLLBACK auszufhren.';  //recently translated
$strShowStatusHandler_updateDescr = 'Anzahl der Anfragen, eine Zeile in einer Tabelle zu aktualisieren.';  //recently translated
$strShowStatusHandler_writeDescr = 'Anzahl der Anfragen, eine Zeile in eine Tabelle einzufgen.';  //recently translated
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'Schlssel-Blcke im Schlssel-Cache, die verndert wurden, aber noch nicht auf die Platte zurck geschrieben (flush). Auch bekannt als Not_flushed_key_blocks.';  //recently translated
$strShowStatusKey_blocks_unusedDescr = 'Die Anzahl der unbenutzten Schlssel-Blcke im Schlssel-Cache. Dieser Wert kann dazu dienen die Auslastung des Schlssel-Cache zu bestimmen.';  //recently translated
$strShowStatusKey_blocks_usedDescr = 'Die Anzahl der maximal gleichzeitig benutzten Blocks im Schlssel-Cache.';  //recently translated
$strShowStatusKey_read_requestsDescr = 'Die Anzahl der Anfragen, einen Schlssel-Block aus dem Cache zu lesen.';  //recently translated
$strShowStatusKey_readsDescr = 'Die Anzahl physikalischer Lesezugriffen eines Schlssel-Blocks von der Platte. Wenn key_reads hoch ist, ist Ihr key_cache wahrscheinlich zu klein. Die Cache-Zugriffsrate kann mit key_reads / key_read_requests berechnet werden.';  //recently translated
$strShowStatusKey_write_requestsDescr = 'Die Anzahl der Anfragen, einen Schlssel-Block in den Cache zu schreiben.';  //recently translated
$strShowStatusKey_writesDescr = 'Die Anzahl physikalischer Schreibvorgnge eines Schlssel-Blocks auf Platte.';  //recently translated
$strShowStatusLast_query_costDescr = 'Die Kosten fr die zuletzt verarbeitete Abfrage wie vom Abfrage-Optmierer berechnet. Ntzlich um verschiedene Formulierungen fr eine Abfrage zu vergleichen. Der Wert 0 besagt das bisher keine Abfrage bersetzt wurde.';  //recently translated
$strShowStatusNot_flushed_delayed_rowsDescr = 'Anzahl der Zeilen, die in INSERT DELAY-Warteschleifen darauf warten, geschrieben zu werden.';  //recently translated
$strShowStatusOpened_tablesDescr = 'Anzahl der Tabellen, die geffnet wurden. Wenn Opened_tables hoch ist, ist Ihre table_cache-Variable wahrscheinlich zu niedrig.';  //recently translated
$strShowStatusOpen_filesDescr = 'Anzahl der offenen Dateien.';  //recently translated
$strShowStatusOpen_streamsDescr = 'Anzahl der offenen Streams (hauptschlich zum Loggen benutzt).';  //recently translated
$strShowStatusOpen_tablesDescr = 'Anzahl der offenen Tabellen.';  //recently translated
$strShowStatusQcache_free_blocksDescr = 'Freie Speicherblcke im Abfrage-Cache.';  //recently translated
$strShowStatusQcache_free_memoryDescr = 'Freier Speicher im Abfrage-Cache.';  //recently translated
$strShowStatusQcache_hitsDescr = 'Abfrage-Cache-Zugriffsrate.';  //recently translated
$strShowStatusQcache_insertsDescr = 'Die Anzahl der Abfragen die dem Cache hinzugefgt wurden.';  //recently translated
$strShowStatusQcache_lowmem_prunesDescr = 'Die Anzahl der Abfragen die aus dem Cache entfernt wurden, um Speicher fr neue Abfragen frei zu geben. Dieser Wert kann helfen die Abfrage-Cache-Gre zu optimieren. Der Abfrage-Cache verwendet die \'am wenigsten gebrauchte\' (least recently used (LRU)) Strategie um zu entscheiden welche Abfrage aus dem Cache gelscht werden.';  //recently translated
$strShowStatusQcache_not_cachedDescr = 'Die Anzahl der nicht im Cache eingetragenen Abfragen (nicht mglich, oder aufgrund der query_cache_type Einstellung).';  //recently translated
$strShowStatusQcache_queries_in_cacheDescr = 'Die Anzahl der Abfragen im Cache.';  //recently translated
$strShowStatusQcache_total_blocksDescr = 'Die Anzahl aller Speicherblcke im Abfrage-Cache.';  //recently translated
$strShowStatusReset = 'Zurcksetzen';  //recently translated
$strShowStatusRpl_statusDescr = 'Der Status der ausfallsicheren Replikation.';  //recently translated
$strShowStatusSelect_full_joinDescr = 'Anzahl der Joins ohne Schlssel. Wenn dieser Wert nicht 0 ist sollten die Indizes der Tabellen sorgfltig berprft werden.';  //recently translated
$strShowStatusSelect_full_range_joinDescr = 'Anzahl der Joins, bei denen eine Bereichssuche auf die Referenztabelle statt fand.';  //recently translated
$strShowStatusSelect_range_checkDescr = 'Anzahl der Joins ohne Schlssel, bei denen nach jeder Zeile auf Schlsselbenutzung geprft wurde. Wenn dieser Wert nicht 0 ist sollten die Indizes der Tabellen sorgfltig berprft werden.';  //recently translated
$strShowStatusSelect_rangeDescr = 'Anzahl der Joins, bei denen Bereiche auf die erste Tabelle benutzt wurden. (Es ist normalerweise unkritisch, wenn dieser Wert hoch ist.)';  //recently translated
$strShowStatusSelect_scanDescr = 'Anzahl der Joins, bei denen die erste Tabelle gescannt wurde.';  //recently translated
$strShowStatusSlave_open_temp_tablesDescr = 'Anzahl der temporren Tabellen, die momentan vom Slave-Thread geffnet sind.';  //recently translated
$strShowStatusSlave_retried_transactionsDescr = 'Gesamtzahl (seit Start des Servers) der vom Replikations-Slave-SQL-Thread widerversuchten Transaktionen.';  //recently translated
$strShowStatusSlave_runningDescr = 'Dieser Wert steht auf ON wenn dieser Server ein Slave ist und mit dem Master verbunden ist.';  //recently translated
$strShowStatusSlow_launch_threadsDescr = 'Anzahl der Threads, die lnger als slow_launch_time  brauchten, um sich zu verbinden.';  //recently translated
$strShowStatusSlow_queriesDescr = 'Anzahl der Anfragen, die lnger als long_query_time bentigten.';  //recently translated
$strShowStatusSort_merge_passesDescr = 'Anzahl der Verschmelzungen (Merge), die von einem Sortiervorgang bentigt wurden. Wenn dieser Wert hoch ist, sollten Sie in Betracht ziehen, sort_buffer  herauf zu setzen.';  //recently translated
$strShowStatusSort_rangeDescr = 'Anzahl der Sortiervorgnge, die mit Bereichen durchgefhrt wurden.';  //recently translated
$strShowStatusSort_rowsDescr = 'Anzahl der sortierten Zeilen.';  //recently translated
$strShowStatusSort_scanDescr = 'Anzahl der Sortiervorgnge, die durchgefhrt wurden, indem die Tabelle gescannt wurde.';  //recently translated
$strShowStatusTable_locks_immediateDescr = 'Wie oft eine Tabellensperre sofort erlangt wurde.';  //recently translated
$strShowStatusTable_locks_waitedDescr = 'Wie oft eine Tabellensperre nicht sofort erlangt werden konnte und gewartet werden musst. Wenn dieser Wert hoch ist und Sie Performance-Probleme haben, sollten Sie zunchst Ihre Anfragen optimieren und dann entweder Ihre Tabelle(n) zerteilen oder Replikation benutzen.';  //recently translated
$strShowStatusThreads_cachedDescr = 'Anzahl der Threads im Thread-Cache. Die Cache-Zugriffsrate kann mit Threads_created / Connections berechnet werden. Wenn dieser Wert rot ist, sollte der thread_cache_size erhht werden.';  //recently translated
$strShowStatusThreads_connectedDescr = 'Anzahl der momentan offenen Verbindungen.';  //recently translated
$strShowStatusThreads_createdDescr = 'Anzahl der Threads, die zur Handhabung von Verbindungen erzeugt wurden. Wenn Threads_created hoch ist, sollten Sie eventuell die Thread_cache_size-Variable herauf setzen. (Normalerweise ergibt sich daraus keine bemerkbare Performance-Steigerung wenn eine gute Thread-Implementierung vorliegt.)';  //recently translated
$strShowStatusThreads_runningDescr = 'Anzahl der Threads, die nicht schlafen.';  //recently translated
$strSkipQueries = 'Anzahl der am Anfang zu berspringenden Eintrge (Abfragen)';  //recently translated
$strSorting = 'Sortierung';  //recently translated

$strTableAlreadyExists = 'Die Tabelle %s existiert bereits!';  //recently translated
$strTempData = 'Temporre Daten';  //recently translated
$strThreads = 'Prozesse';  //recently translated
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate

$strUploadLimit = 'Mglicherweise wurde eine zu groe Datei hochgeladen. Bitte schauen Sie in die %sDokumentation%s zur Lsung diese Problems.';  //recently translated

?>
